package
Version:
v0.1.0-alpha.2
Opens a new window with list of versions in this module.
Published: Dec 3, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Address string
ProxyMode bool
}
TODO: look at "github.com/knadh/koanf/v2"
Source Files
¶
Click to show internal directories.
Click to hide internal directories.